==> aws-cdk-lib-2.0.0-rc.14-sources.jar: software/amazon/awscdk/services/route53/SrvRecordProps.java <==
package software.amazon.awscdk.services.route53;

/**
 * (experimental) Construction properties for a SrvRecord.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T10:24:35.871Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_route53.SrvRecordProps")
@software.amazon.jsii.Jsii.Proxy(SrvRecordProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface SrvRecordProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.route53.RecordSetOptions {

    /**
     * (experimental) The values.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.route53.SrvRecordValue> getValues();

    /**
     * @return a {@link Builder} of {@link SrvRecordProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SrvRecordProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<SrvRecordProps> {
        private java.util.List<software.amazon.awscdk.services.route53.SrvRecordValue> values;
        private software.amazon.awscdk.services.route53.IHostedZone zone;
        private java.lang.String comment;
        private java.lang.String recordName;
        private software.amazon.awscdk.Duration ttl;

        /**
         * Sets the value of {@link SrvRecordProps#getValues}
         * @param values The values. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder values(java.util.List<? extends software.amazon.awscdk.services.route53.SrvRecordValue> values) {
            this.values = (java.util.List<software.amazon.awscdk.services.route53.SrvRecordValue>)values;
            return this;
        }

        /**
         * Sets the value of {@link SrvRecordProps#getZone}
         * @param zone The hosted zone in which to define the new record. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder zone(software.amazon.awscdk.services.route53.IHostedZone zone) {
            this.zone = zone;
            return this;
        }

        /**
         * Sets the value of {@link SrvRecordProps#getComment}
         * @param comment A comment to add on the record.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder comment(java.lang.String comment) {
            this.comment = comment;
            return this;
        }

        /**
         * Sets the value of {@link SrvRecordProps#getRecordName}
         * @param recordName The domain name for this record.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder recordName(java.lang.String recordName) {
            this.recordName = recordName;
            return this;
        }

        /**
         * Sets the value of {@link SrvRecordProps#getTtl}
         * @param ttl The resource record cache time to live (TTL).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ttl(software.amazon.awscdk.Duration ttl) {
            this.ttl = ttl;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SrvRecordProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public SrvRecordProps build() {
            return new Jsii$Proxy(values, zone, comment, recordName, ttl);
        }
    }

    /**
     * An implementation for {@link SrvRecordProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SrvRecordProps {
        private final java.util.List<software.amazon.awscdk.services.route53.SrvRecordValue> values;
        private final software.amazon.awscdk.services.route53.IHostedZone zone;
        private final java.lang.String comment;
        private final java.lang.String recordName;
        private final software.amazon.awscdk.Duration ttl;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.values = software.amazon.jsii.Kernel.get(this, "values", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.route53.SrvRecordValue.class)));
            this.zone = software.amazon.jsii.Kernel.get(this, "zone", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.route53.IHostedZone.class));
            this.comment = software.amazon.jsii.Kernel.get(this, "comment", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.recordName = software.amazon.jsii.Kernel.get(this, "recordName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ttl = software.amazon.jsii.Kernel.get(this, "ttl", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.Duration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.util.List<? extends software.amazon.awscdk.services.route53.SrvRecordValue> values, final software.amazon.awscdk.services.route53.IHostedZone zone, final java.lang.String comment, final java.lang.String recordName, final software.amazon.awscdk.Duration ttl) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.values = (java.util.List<software.amazon.awscdk.services.route53.SrvRecordValue>)java.util.Objects.requireNonNull(values, "values is required");
            this.zone = java.util.Objects.requireNonNull(zone, "zone is required");
            this.comment = comment;
            this.recordName = recordName;
            this.ttl = ttl;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.route53.SrvRecordValue> getValues() {
            return this.values;
        }

        @Override
        public final software.amazon.awscdk.services.route53.IHostedZone getZone() {
            return this.zone;
        }

        @Override
        public final java.lang.String getComment() {
            return this.comment;
        }

        @Override
        public final java.lang.String getRecordName() {
            return this.recordName;
        }

        @Override
        public final software.amazon.awscdk.Duration getTtl() {
            return this.ttl;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("values", om.valueToTree(this.getValues()));
            data.set("zone", om.valueToTree(this.getZone()));
            if (this.getComment() != null) {
                data.set("comment", om.valueToTree(this.getComment()));
            }
            if (this.getRecordName() != null) {
                data.set("recordName", om.valueToTree(this.getRecordName()));
            }
            if (this.getTtl() != null) {
                data.set("ttl", om.valueToTree(this.getTtl()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_route53.SrvRecordProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SrvRecordProps.Jsii$Proxy that = (SrvRecordProps.Jsii$Proxy) o;

            if (!values.equals(that.values)) return false;
            if (!zone.equals(that.zone)) return false;
            if (this.comment != null ? !this.comment.equals(that.comment) : that.comment != null) return false;
            if (this.recordName != null ? !this.recordName.equals(that.recordName) : that.recordName != null) return false;
            return this.ttl != null ? this.ttl.equals(that.ttl) : that.ttl == null;
        }

        @Override
        public final int hashCode() {
            int result = this.values.hashCode();
            result = 31 * result + (this.zone.hashCode());
            result = 31 * result + (this.comment != null ? this.comment.hashCode() : 0);
            result = 31 * result + (this.recordName != null ? this.recordName.hashCode() : 0);
            result = 31 * result + (this.ttl != null ? this.ttl.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/route53/SrvRecordProps.java <==
package software.amazon.awscdk.services.route53;

/**
 * Construction properties for a SrvRecord.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.*;
 * import software.amazon.awscdk.services.route53.*;
 * HostedZone hostedZone;
 * SrvRecordProps srvRecordProps = SrvRecordProps.builder()
 *         .values(List.of(SrvRecordValue.builder()
 *                 .hostName("hostName")
 *                 .port(123)
 *                 .priority(123)
 *                 .weight(123)
 *                 .build()))
 *         .zone(hostedZone)
 *         // the properties below are optional
 *         .comment("comment")
 *         .recordName("recordName")
 *         .ttl(Duration.minutes(30))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:12.420Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_route53.SrvRecordProps")
@software.amazon.jsii.Jsii.Proxy(SrvRecordProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SrvRecordProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.route53.RecordSetOptions {

    /**
     * The values.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.route53.SrvRecordValue> getValues();

    /**
     * @return a {@link Builder} of {@link SrvRecordProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SrvRecordProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SrvRecordProps> {
        java.util.List<software.amazon.awscdk.services.route53.SrvRecordValue> values;
        software.amazon.awscdk.services.route53.IHostedZone zone;
        java.lang.String comment;
        java.lang.String recordName;
        software.amazon.awscdk.Duration ttl;

        /**
         * Sets the value of {@link SrvRecordProps#getValues}
         * @param values The values. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder values(java.util.List<? extends software.amazon.awscdk.services.route53.SrvRecordValue> values) {
            this.values = (java.util.List<software.amazon.awscdk.services.route53.SrvRecordValue>)values;
            return this;
        }

        /**
         * Sets the value of {@link SrvRecordProps#getZone}
         * @param zone The hosted zone in which to define the new record. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder zone(software.amazon.awscdk.services.route53.IHostedZone zone) {
            this.zone = zone;
            return this;
        }

        /**
         * Sets the value of {@link SrvRecordProps#getComment}
         * @param comment A comment to add on the record.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder comment(java.lang.String comment) {
            this.comment = comment;
            return this;
        }

        /**
         * Sets the value of {@link SrvRecordProps#getRecordName}
         * @param recordName The domain name for this record.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder recordName(java.lang.String recordName) {
            this.recordName = recordName;
            return this;
        }

        /**
         * Sets the value of {@link SrvRecordProps#getTtl}
         * @param ttl The resource record cache time to live (TTL).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ttl(software.amazon.awscdk.Duration ttl) {
            this.ttl = ttl;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SrvRecordProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SrvRecordProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SrvRecordProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SrvRecordProps {
        private final java.util.List<software.amazon.awscdk.services.route53.SrvRecordValue> values;
        private final software.amazon.awscdk.services.route53.IHostedZone zone;
        private final java.lang.String comment;
        private final java.lang.String recordName;
        private final software.amazon.awscdk.Duration ttl;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.values = software.amazon.jsii.Kernel.get(this, "values", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.route53.SrvRecordValue.class)));
            this.zone = software.amazon.jsii.Kernel.get(this, "zone", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.route53.IHostedZone.class));
            this.comment = software.amazon.jsii.Kernel.get(this, "comment", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.recordName = software.amazon.jsii.Kernel.get(this, "recordName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ttl = software.amazon.jsii.Kernel.get(this, "ttl", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.Duration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.values = (java.util.List<software.amazon.awscdk.services.route53.SrvRecordValue>)java.util.Objects.requireNonNull(builder.values, "values is required");
            this.zone = java.util.Objects.requireNonNull(builder.zone, "zone is required");
            this.comment = builder.comment;
            this.recordName = builder.recordName;
            this.ttl = builder.ttl;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.route53.SrvRecordValue> getValues() {
            return this.values;
        }

        @Override
        public final software.amazon.awscdk.services.route53.IHostedZone getZone() {
            return this.zone;
        }

        @Override
        public final java.lang.String getComment() {
            return this.comment;
        }

        @Override
        public final java.lang.String getRecordName() {
            return this.recordName;
        }

        @Override
        public final software.amazon.awscdk.Duration getTtl() {
            return this.ttl;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("values", om.valueToTree(this.getValues()));
            data.set("zone", om.valueToTree(this.getZone()));
            if (this.getComment() != null) {
                data.set("comment", om.valueToTree(this.getComment()));
            }
            if (this.getRecordName() != null) {
                data.set("recordName", om.valueToTree(this.getRecordName()));
            }
            if (this.getTtl() != null) {
                data.set("ttl", om.valueToTree(this.getTtl()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_route53.SrvRecordProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SrvRecordProps.Jsii$Proxy that = (SrvRecordProps.Jsii$Proxy) o;

            if (!values.equals(that.values)) return false;
            if (!zone.equals(that.zone)) return false;
            if (this.comment != null ? !this.comment.equals(that.comment) : that.comment != null) return false;
            if (this.recordName != null ? !this.recordName.equals(that.recordName) : that.recordName != null) return false;
            return this.ttl != null ? this.ttl.equals(that.ttl) : that.ttl == null;
        }

        @Override
        public final int hashCode() {
            int result = this.values.hashCode();
            result = 31 * result + (this.zone.hashCode());
            result = 31 * result + (this.comment != null ? this.comment.hashCode() : 0);
            result = 31 * result + (this.recordName != null ? this.recordName.hashCode() : 0);
            result = 31 * result + (this.ttl != null ? this.ttl.hashCode() : 0);
            return result;
        }
    }
}
